//
//  RHViewController.m
//  TicTacToe
//
//  Created by Jimmy Theis on 3/19/12.
//  Copyright (c) 2012 Rose-Hulman Institute of Technology. All rights reserved.
//

#import "RHViewController.h"
#import "RHTicTacToeGame.h"


@interface RHViewController ()

@property (nonatomic, strong) RHTicTacToeGame *game;
@property (nonatomic, readonly) UIImage *xImage;
@property (nonatomic, readonly) UIImage *oImage;

- (void)updateView;

@end


@implementation RHViewController

@synthesize userMessageLabel = _userMessageLabel;
@synthesize game = _game;

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Release any cached data, images, etc that aren't in use.
}

#pragma mark - View lifecycle

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    self.game = [[RHTicTacToeGame alloc] init];
    [self updateView];
}

- (void)viewDidUnload
{
    [super viewDidUnload];
    // Release any retained subviews of the main view.
    // e.g. self.myOutlet = nil;
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
}

- (void)viewWillDisappear:(BOOL)animated
{
	[super viewWillDisappear:animated];
}

- (void)viewDidDisappear:(BOOL)animated
{
	[super viewDidDisappear:animated];
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
    // Return YES for supported orientations
    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
}

#pragma mark - IBActions

- (void)pressedReset:(id)sender {
    [self.game resetBoard];
    [self updateView];
}

- (void)pressedBoardSquare:(id)sender {
    UIButton *button = (UIButton *) sender;
    NSInteger rowClicked = button.tag / 10 % 10;
    NSInteger columnClicked = button.tag % 10;
    
    [self.game playerPressedRow:rowClicked column:columnClicked];
    [self updateView];
}

#pragma mark - Private Methods

- (UIImage *)xImage {
    return [UIImage imageNamed:@"X.png"];
}

- (UIImage *)oImage {
    return [UIImage imageNamed:@"O.png"];
}

- (void)updateView { 
    switch (self.game.gameState) {
        case RHTicTacToeGameStateXTurn:
            self.userMessageLabel.text = @"X's Turn";
            break;
            
        case RHTicTacToeGameStateOTurn:
            self.userMessageLabel.text = @"O's Turn";
            break;
            
        case RHTicTacToeGameStateXWon:
            self.userMessageLabel.text = @"X Wins!";
            break;
            
        case RHTicTacToeGameStateOWon:
            self.userMessageLabel.text = @"O Wins!";
            break;
            
        case RHTicTacToeGameStateTie:
            self.userMessageLabel.text = @"Tie Game";
            break;
            
        default:
            break;
    }
    
    for (int r = 0; r < kRHNumRows; r++) {
        for (int c = 0; c < kRHNumColumns; c++) {
            UIButton *button = (UIButton *) [self.view viewWithTag:1000 + (r * 10) + c];
            
            switch ([self.game getMarkInRow:r column:c]) {
                case RHTicTacToeMarkX:
                    [button setImage:self.xImage forState:UIControlStateNormal];
                    break;
                    
                case RHTicTacToeMarkO:
                    [button setImage:self.oImage forState:UIControlStateNormal];
                    break;
                    
                case RHTicTacToeMarkNone:
                    [button setImage:nil forState:UIControlStateNormal];
                    break;
                    
                default:
                    break;
            }
        }
    }
    
}

@end
